==> nine_lifes-1.7%2B1.21.6-sources.jar: com/bleudev/nine_lifes/custom/entity/WanderingArmorStandEntity.java <==
package com.bleudev.nine_lifes.custom.entity;

import com.bleudev.nine_lifes.custom.entity.ai.goal.WanderingArmorStandLookAroundGoal;
import com.bleudev.nine_lifes.networking.payloads.ArmorStandHitEventPayload;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1314;
import net.minecraft.class_1361;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_8111;

public class WanderingArmorStandEntity extends class_1314 {
    private static final class_2940<Boolean> IS_ALIVE;

    public WanderingArmorStandEntity(class_1299<? extends class_1314> entityType, class_1937 world) {
        super(entityType, world);
        this.method_6033(1);
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {
        super.method_5693(builder);
        builder.method_56912(IS_ALIVE, false);
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(1, new class_1391(this, 0.4, (stack) -> stack.method_31574(class_1802.field_27063), false));
        this.field_6201.method_6277(2, new class_1394(this, 0.3) {
            @Override
            public boolean method_6264() {
                if (((WanderingArmorStandEntity) field_6566).cannotWander()) return false;
                return super.method_6264();
            }
        });
        this.field_6201.method_6277(3, new class_1361(this, class_1657.class, 6f) {
            @Override
            public boolean method_6264() {
                if (((WanderingArmorStandEntity) field_6486).cannotWander()) return false;
                return super.method_6264();
            }
        });
        this.field_6201.method_6277(4, new WanderingArmorStandLookAroundGoal(this));
    }

    public static class_5132.class_5133 method_26827() {
        return class_1309.method_26827()
                .method_26868(class_5134.field_23716, 1)
                .method_26867(class_5134.field_23717)
                .method_26867(class_5134.field_52450);
    }

    @Override
    public boolean method_5822(boolean allowVehicles) {
        return false;
    }

    @Override
    public boolean method_49108() {
        return false;
    }

    @Override
    protected boolean method_63628() {
        return false;
    }

    @Override
    public boolean method_6094() {
        return true;
    }

    @Override
    public boolean method_5810() {
        return false;
    }

    @Override
    protected void method_6087(class_1297 entity) {
    }

    @Override
    public void method_5697(class_1297 entity) {
    }

    @Override
    public void method_5768(class_3218 world) {
        if (!world.field_9236) {
            this.method_5650(class_5529.field_26998);
        }
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        if (source.method_5529() instanceof class_3222 player)
            ServerPlayNetworking.send(player, new ArmorStandHitEventPayload(method_19538()));
        return source.method_49708(class_8111.field_44869);
    }

    @Override
    public boolean method_5679(class_3218 world, class_1282 source) {
        return !source.method_49708(class_8111.field_44869);
    }

    public boolean cannotWander() {
        return (!this.field_6011.method_12789(IS_ALIVE));
    }

    public void setWander(boolean is_alive) {
        this.field_6011.method_12778(IS_ALIVE, is_alive);
    }

    private static void spawnParticle(class_2394 particle, class_3218 world, class_243 pos) {
        double offsetX = (world.field_9229.method_43058() - 0.5) * 2.0;
        double offsetY = world.field_9229.method_43058() * 2.0;
        double offsetZ = (world.field_9229.method_43058() - 0.5) * 2.0;

        world.method_65096(particle,
            pos.method_10216() + offsetX, pos.method_10214() + offsetY, pos.method_10215() + offsetZ,
            1, 0, 0, 0, 1
        );
    }

    public class_1269 method_5992(class_1657 player, class_1268 hand) {
        class_1799 stack = player.method_6047();
        // Eat
        if (stack.method_31574(class_1802.field_27063)) {
            if (method_37908() instanceof class_3218 world) {
                var pos = method_19538();
                for (int i = 0; i < 3; i++)
                    spawnParticle(class_2398.field_11201, world, pos);
            }

            // Consume amethyst shard
            if (!player.method_68878()) {
                if (stack.method_7947() == 1)
                    player.method_6122(hand, class_1799.field_8037);
                else {
                    stack.method_7939(stack.method_7947() - 1);
                    player.method_6122(hand, stack);
                }
            }

            setWander(true);
            return class_1269.field_5812;
        }
        return super.method_5992(player, hand);
    }

    static {
        IS_ALIVE = class_2945.method_12791(WanderingArmorStandEntity.class, class_2943.field_13323);
    }
}

==> nine_lifes-1.9.0%2B1.21.9-sources.jar: com/bleudev/nine_lifes/custom/entity/WanderingArmorStandEntity.java <==
package com.bleudev.nine_lifes.custom.entity;

import com.bleudev.nine_lifes.custom.entity.ai.goal.WanderingArmorStandLookAroundGoal;
import com.bleudev.nine_lifes.networking.payloads.ArmorStandHitEvent;
import net.fabricmc.fabric.api.networking.v1.ServerPlayNetworking;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1314;
import net.minecraft.class_1361;
import net.minecraft.class_1391;
import net.minecraft.class_1394;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_2940;
import net.minecraft.class_2943;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_5132;
import net.minecraft.class_5134;
import net.minecraft.class_8111;

import static com.bleudev.nine_lifes.compat.VersionCompat.getPosCompat;
import static com.bleudev.nine_lifes.compat.VersionCompat.getWorldCompat;

public class WanderingArmorStandEntity extends class_1314 {
    private static final class_2940<Boolean> IS_ALIVE;

    public WanderingArmorStandEntity(class_1299<? extends class_1314> entityType, class_1937 world) {
        super(entityType, world);
        this.method_6033(1);
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {
        super.method_5693(builder);
        builder.method_56912(IS_ALIVE, false);
    }

    @Override
    protected void method_5959() {
        super.method_5959();
        this.field_6201.method_6277(1, new class_1391(this, 0.4, (stack) -> stack.method_31574(class_1802.field_27063), false));
        this.field_6201.method_6277(2, new class_1394(this, 0.3) {
            @Override
            public boolean method_6264() {
                if (((WanderingArmorStandEntity) field_6566).cannotWander()) return false;
                return super.method_6264();
            }
        });
        this.field_6201.method_6277(3, new class_1361(this, class_1657.class, 6f) {
            @Override
            public boolean method_6264() {
                if (((WanderingArmorStandEntity) field_6486).cannotWander()) return false;
                return super.method_6264();
            }
        });
        this.field_6201.method_6277(4, new WanderingArmorStandLookAroundGoal(this));
    }

    public static class_5132.class_5133 method_26827() {
        return class_1309.method_26827()
                .method_26868(class_5134.field_23716, 1)
                .method_26867(class_5134.field_23717)
                .method_26867(class_5134.field_52450);
    }

    @Override
    public boolean method_5822(boolean allowVehicles) {
        return false;
    }

    @Override
    public boolean method_49108() {
        return false;
    }

    @Override
    protected boolean method_63628() {
        return false;
    }

    @Override
    public boolean method_6094() {
        return true;
    }

    @Override
    public boolean method_5810() {
        return false;
    }

    @Override
    protected void method_6087(class_1297 entity) {
    }

    @Override
    public void method_5697(class_1297 entity) {
    }

    @Override
    public void method_5768(class_3218 world) {
        if (!world.method_8608()) {
            this.method_5650(class_5529.field_26998);
        }
    }

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        if (source.method_5529() instanceof class_3222 player)
            ServerPlayNetworking.send(player, new ArmorStandHitEvent(getPosCompat(this)));
        return source.method_49708(class_8111.field_44869);
    }

    @Override
    public boolean method_5679(class_3218 world, class_1282 source) {
        return !source.method_49708(class_8111.field_44869);
    }

    public boolean cannotWander() {
        return (!this.field_6011.method_12789(IS_ALIVE));
    }

    public void setWander(boolean is_alive) {
        this.field_6011.method_12778(IS_ALIVE, is_alive);
    }

    private static void spawnParticle(class_2394 particle, class_3218 world, class_243 pos) {
        double offsetX = (world.field_9229.method_43058() - 0.5) * 2.0;
        double offsetY = world.field_9229.method_43058() * 2.0;
        double offsetZ = (world.field_9229.method_43058() - 0.5) * 2.0;

        world.method_65096(particle,
            pos.method_10216() + offsetX, pos.method_10214() + offsetY, pos.method_10215() + offsetZ,
            1, 0, 0, 0, 1
        );
    }

    public class_1269 method_5992(class_1657 player, class_1268 hand) {
        class_1799 stack = player.method_6047();
        // Eat
        if (stack.method_31574(class_1802.field_27063)) {
            if (getWorldCompat(this) instanceof class_3218 world) {
                var pos = getPosCompat(this);
                for (int i = 0; i < 3; i++)
                    spawnParticle(class_2398.field_11201, world, pos);
            }

            // Consume amethyst shard
            if (!player.method_68878()) {
                if (stack.method_7947() == 1)
                    player.method_6122(hand, class_1799.field_8037);
                else {
                    stack.method_7939(stack.method_7947() - 1);
                    player.method_6122(hand, stack);
                }
            }

            setWander(true);
            return class_1269.field_5812;
        }
        return super.method_5992(player, hand);
    }

    static {
        IS_ALIVE = class_2945.method_12791(WanderingArmorStandEntity.class, class_2943.field_13323);
    }
}
